@@ -11,11 +11,11 @@ Test::Regression - Test library that can be run in two modes; one to generate ou
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =cut
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 =head1 SYNOPSIS
 
@@ -60,7 +60,7 @@ There is a third optional argument which is the test name.
 sub ok_regression {
     my $code_ref  = shift;
     my $file      = shift;
-    my $test_name = shift;
+    my $test_name = shift || "unnamed regression test";
     my $output    = eval { &$code_ref(); };
     my $tb        = $CLASS->builder;
     if ($@) {
